.. _REST_API:

********
REST API
********

Communication between SFChat server and Front-end arranges by REST Api using JSON data format.

.. toctree::
   :maxdepth: 4
   :titlesonly:

   Endpoint
   Versioning
   URL Example
   Authorization
   Authentication   
   Resources/index
